HCColorAxisLabelsOptions class
(Highcharts, Highstock, Highmaps) The axis labels show the number for each tick.
- Implemented types
Constructors
-
HCColorAxisLabelsOptions({String? align, bool? allowOverlap, List<
num> ? autoRotation, num? autoRotationLimit, num? distance, bool? enabled, String? format, num? maxStaggerLines, String? overflow, num? padding, String? position3d, bool? reserveSpace, num? rotation, bool? skew3d, num? staggerLines, num? step, dynamic style, bool? useHTML, num? x, num? y, num? zIndex}) -
const
Properties
- align → String?
-
(Highcharts, Highstock, Highmaps) What part of the string the given position is anchored to. If
left, the left side of the string is at the axis position. Can be one of"left","center"or"right". Defaults to an intelligent guess based on which side of the chart the axis is on and the rotatfinal - allowOverlap → bool?
-
(Highcharts, Highstock, Highmaps) Whether to allow the axis labels to overlap. When false, overlapping labels are hidden.
final
-
autoRotation
→ List<
num> ? -
(Highcharts, Highstock, Gantt) For horizontal axes, the allowed degrees of label rotation to prevent overlapping labels. If there is enough space, labels are not rotated. As the chart gets narrower, it will start rotating the labels -45 degrees, then remove every second label and try again with rota
final
- autoRotationLimit → num?
-
(Highcharts, Gantt) When each category width is more than this many pixels, we don't apply auto rotation. Instead, we lay out the axis label with word wrap. A lower limit makes sense when the label contains multiple short words that don't extend the available horizontal space for each label.
final
- distance → num?
-
(Highcharts, Gantt) The label's pixel distance from the perimeter of the plot area. On cartesian charts, this is overridden if the
labels.ysetting is set.final - enabled → bool?
-
(Highcharts, Highstock, Highmaps) Enable or disable the axis labels.
final
- format → String?
-
(Highcharts, Highstock, Highmaps) A format string for the axis label. The context is available as format string variables. For example, you can use
{text}to insert the default formatted text. The recommended way of adding units for the label is usingtext, for example{text} km.final - hashCode → int
-
The hash code for this object.
no setterinherited
- maxStaggerLines → num?
-
(Highcharts, Highstock, Highmaps) Horizontal axis only. When
staggerLinesis not set,maxStaggerLinesdefines how many lines the axis is allowed to add to automatically avoid overlapping X labels. Set to1to disable overlap detection.final - overflow → String?
-
(Highcharts, Highstock, Highmaps) How to handle overflowing labels on horizontal color axis. If set to
"allow", it will not be aligned at all. By default it"justify"labels inside the chart area. If there is room to move it, it will be aligned to the edge, else it will be removed.final - padding → num?
-
(Highcharts, Gantt) The pixel padding for axis labels, to ensure white space between them. Defaults to 4 for horizontal axes, 1 for vertical.
final
- position3d → String?
-
(Highcharts) Defines how the labels are be repositioned according to the 3D chart orientation.
final
- reserveSpace → bool?
-
(Highcharts, Highstock, Gantt) Whether to reserve space for the labels. By default, space is reserved for the labels in these cases:
final
- rotation → num?
-
(Highcharts, Highstock, Highmaps) Rotation of the labels in degrees. When
undefined, theautoRotationoption takes precedence.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skew3d → bool?
-
(Highcharts) If enabled, the axis labels will skewed to follow the perspective.
final
- staggerLines → num?
-
(Highcharts, Highstock, Highmaps) Horizontal axes only. The number of lines to spread the labels over to make room or tighter labels. 0 disables staggering.
final
- step → num?
-
(Highcharts, Highstock, Highmaps) To show only every n'th label on the axis, set the step to n. Setting the step to 2 shows every other label.
final
- style → dynamic
-
(Highcharts, Highstock, Highmaps) CSS styles for the label. Use
lineClampto control wrapping of category labels. UsetextOverflow: 'none'to prevent ellipsis (dots).final - useHTML → bool?
-
(Highcharts, Highstock, Highmaps) Whether to use HTML to render the labels.
final
- x → num?
-
(Highcharts, Highstock, Highmaps) The x position offset of all labels relative to the tick positions on the axis. Overrides the
labels.distanceoption.final - y → num?
-
(Highcharts, Highstock, Highmaps) The y position offset of all labels relative to the tick positions on the axis. Overrides the
labels.distanceoption.final - zIndex → num?
-
(Highcharts, Highstock, Highmaps) The Z index for the axis labels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited