HCLangAccessibilitySeriesSummaryOptions class

(Highcharts, Highstock, Highmaps, Gantt) Lang configuration for the series main summary. Each series type has two modes:

Implemented types

Constructors

HCLangAccessibilitySeriesSummaryOptions({String? bar, String? barCombination, String? boxplot, String? boxplotCombination, String? bubble, String? bubbleCombination, String? column, String? columnCombination, String? default_, String? defaultCombination, String? line, String? lineCombination, String? map, String? mapbubble, String? mapbubbleCombination, String? mapCombination, String? mapline, String? maplineCombination, String? pie, String? pieCombination, String? scatter, String? scatterCombination, String? spline, String? splineCombination})
const

Properties

bar String?
final
barCombination String?
final
boxplot String?
final
boxplotCombination String?
final
bubble String?
final
bubbleCombination String?
final
column String?
final
columnCombination String?
final
default_ String?
final
defaultCombination String?
final
hashCode int
The hash code for this object.
no setterinherited
line String?
final
lineCombination String?
final
map String?
final
mapbubble String?
final
mapbubbleCombination String?
final
mapCombination String?
final
mapline String?
final
maplineCombination String?
final
pie String?
final
pieCombination String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scatter String?
final
scatterCombination String?
final
spline String?
final
splineCombination String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited