HCNavigationBindingsElliott5AnnotationsTypesMeasureTypeOptions class

(Highstock) Additional options for an annotation with the type.

Implemented types

Properties

background HCNavigationBindingsElliott5AnnotationsTypesMeasureTypeBackgroundOptions?
final
crosshairX HCNavigationBindingsElliott5AnnotationsTypesMeasureTypeCrosshairXOptions?
(Highstock) Configure a crosshair that is horizontally placed in middle of rectangle.
final
crosshairY HCNavigationBindingsElliott5AnnotationsTypesMeasureTypeCrosshairYOptions?
(Highstock) Configure a crosshair that is vertically placed in middle of rectangle.
final
hashCode int
The hash code for this object.
no setterinherited
label HCNavigationBindingsElliott5AnnotationsTypesMeasureTypeLabelOptions?
final
line HCNavigationBindingsElliott5AnnotationsTypesMeasureTypeLineOptions?
(Highstock) Line options.
final
points List<HCNavigationBindingsElliott5AnnotationsTypesMeasureTypePointsOptions>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectType String?
(Highstock) Decides in what dimensions the user can resize by dragging the mouse. Can be one of x, y or xy.
final
xAxis num?
(Highstock) This number defines which xAxis the point is connected to. It refers to either the axis id or the index of the axis in the xAxis array.
final
yAxis num?
(Highstock) This number defines which yAxis the point is connected to. It refers to either the axis id or the index of the axis in the yAxis array.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited