HCNavigationBindingsInfinityLineAnnotationsTypesFibonacciTimeZonesOptions class
(Highstock) Options for the fibonacci time zones annotation type.
- Implemented types
Constructors
-
const
Properties
- controlPointOptions → HCAnnotationControlPointOptionsObject?
-
(Highstock) Options for annotation's control points. Each control point inherits options from controlPointOptions object. Options from the controlPointOptions can be overwritten by options in a specific control point.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelOptions → HCNavigationBindingsInfinityLineAnnotationsTypesFibonacciTimeZonesLabelOptions?
-
(Highstock) Options for annotation's labels. Each label inherits options from the labelOptions object. An option from the labelOptions can be overwritten by config for a specific label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeOptions → HCNavigationBindingsInfinityLineAnnotationsTypesFibonacciTimeZonesTypeOptions?
-
(Highstock) Additional options for an annotation with the type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited