HCNavigationBindingsParallelChannelAnnotationsTypesElliottWaveTypeOptions class

(Highstock) Additional options for an annotation with the type.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
line HCNavigationBindingsParallelChannelAnnotationsTypesElliottWaveTypeLineOptions?
(Highstock) Line options.
final
points List<HCNavigationBindingsParallelChannelAnnotationsTypesElliottWaveTypePointsOptions>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xAxis num?
(Highstock) This number defines which xAxis the point is connected to. It refers to either the axis id or the index of the axis in the xAxis array.
final
yAxis num?
(Highstock) This number defines which yAxis the point is connected to. It refers to either the axis id or the index of the axis in the xAxis array.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited