HCNavigatorXAxisGridOptions class

(Gantt) Set grid options for the axis labels. Requires Highcharts Gantt.

Implemented types

Constructors

HCNavigatorXAxisGridOptions({String? borderColor, num? borderWidth, num? cellHeight, List<HCXAxisOptions>? columns, bool? enabled})
const

Properties

borderColor String?
(Gantt) Set border color for the label grid lines.
final
borderWidth num?
(Gantt) Set border width of the label grid lines.
final
cellHeight num?
(Gantt) Set cell height for grid axis labels. By default this is calculated from font size. This option only applies to horizontal axes. For vertical axes, check the .yAxis.staticScale option.
final
columns List<HCXAxisOptions>?
(Gantt) Set specific options for each column (or row for horizontal axes) in the grid. Each extra column/row is its own axis, and the axis options can be set here.
final
enabled bool?
(Gantt) Enable grid on the axis labels. Defaults to true for Gantt charts.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited