HCPlotAdParamsOptions class
(Highstock) Parameters used in calculation of regression series' points.
- Implemented types
Constructors
- HCPlotAdParamsOptions({String? index, num? period, String? volumeSeriesID})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → String?
-
final
- period → num?
-
(Highstock) The base period for indicator calculations. This is the number of data points which are taken into account for the indicator calculations.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- volumeSeriesID → String?
-
(Highstock) The id of volume series which is mandatory. For example using OHLC data, volumeSeriesID='volume' means the indicator will be calculated using OHLC and volume values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited