HCPlotBbOnPointOptions class
(Highstock) Options for the Series on point feature. Only pie and sunburst series are supported at this moment.
- Implemented types
Constructors
- HCPlotBbOnPointOptions({dynamic connectorOptions, String? id, dynamic position})
-
const
Properties
- connectorOptions → dynamic
-
(Highstock) Options for the connector in the Series on point feature.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
(Highstock) The
idof the point that we connect the series to. Only points with a givenplotXandplotYvalues and map points are valid.final - position → dynamic
-
(Highstock) Options allowing to set a position and an offset of the series in the Series on point feature.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited