shape property
(Highstock) The name of a symbol to use for the border around the tooltip header. Applies only when tooltip.split is enabled.
Implementation
final String? shape;
(Highstock) The name of a symbol to use for the border around the tooltip header. Applies only when tooltip.split is enabled.
final String? shape;