HCPlotLinearregressionDataSortingOptions class

(Highcharts, Highstock) Options for series data sorting.

Implemented types

Constructors

HCPlotLinearregressionDataSortingOptions({bool? enabled, bool? matchByName, String? sortKey})
const

Properties

enabled bool?
(Highcharts, Highstock) Enable or disable data sorting for the series. Use xAxis.reversed to change the sorting order.
final
hashCode int
The hash code for this object.
no setterinherited
matchByName bool?
(Highcharts, Highstock) Whether to allow matching points by name in an update. If this option is disabled, points will be matched by order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortKey String?
(Highcharts, Highstock) Determines what data value should be used to sort by.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited