HCPlotSmaDataLabelsAnimationOptions class

(Highcharts, Highstock, Highmaps, Gantt) Enable or disable the initial animation when a series is displayed for the dataLabels. The animation can also be set as a configuration object. Please note that this option only applies to the initial animation.

Implemented types

Constructors

HCPlotSmaDataLabelsAnimationOptions({num? defer})
const

Properties

defer num?
(Highcharts, Highstock, Highmaps, Gantt) The animation delay time in milliseconds. Set to 0 to render the data labels immediately. As undefined inherits defer time from the series.animation.defer.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited