HCPlotSupertrendDataLabelsOptions class
(Highcharts, Highstock, Highmaps, Gantt) Options for the series data labels, appearing next to each data point.
- Implemented types
Constructors
- HCPlotSupertrendDataLabelsOptions({String? align, String? alignTo, bool? allowOverlap, dynamic animation, dynamic backgroundColor, dynamic borderColor, num? borderRadius, num? borderWidth, String? className, dynamic color, bool? crop, bool? defer, num? distance, bool? enabled, HCDataLabelsFilterOptionsObject? filter, String? format, bool? inside, num? labelrank, dynamic nullFormat, String? overflow, dynamic padding, String? position, num? rotation, dynamic shadow, String? shape, HCCSSObject? style, HCDataLabelsTextPathOptionsObject? textPath, bool? useHTML, String? verticalAlign, num? x, num? y, num? zIndex})
-
const
Properties
- align → String?
-
(Highcharts, Highstock, Highmaps, Gantt) The alignment of the data label compared to the point. If
right, the right side of the label should be touching the point. For points with an extent, like columns, the alignments also dictates how to align it inside the box, as given with the inside option.final - alignTo → String?
-
(Highcharts, Highstock, Highmaps, Gantt) Alignment method for data labels. If set to
plotEdges, the labels are aligned within the plot area in the direction of the y-axis. So in a regular column chart, the labels are aligned vertically according to theverticalAlignsetting. In a bar chart, whicfinal - allowOverlap → bool?
-
(Highcharts, Highstock, Highmaps, Gantt) Whether to allow data labels to overlap. To make the labels less sensitive for overlapping, the dataLabels.padding can be set to 0.
final
- animation → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) Enable or disable the initial animation when a series is displayed for the
dataLabels. The animation can also be set as a configuration object. Please note that this option only applies to the initial animation.final - backgroundColor → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) The background color or gradient for the data label. In addition to regular colors, there are two special setting for this option:
final
- borderColor → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) The border color for the data label. Setting it to
autowill use the point's color. Defaults toundefined.final - borderRadius → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The border radius in pixels for the data label.
final
- borderWidth → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The border width in pixels for the data label.
final
- className → String?
-
(Highcharts, Highstock, Highmaps, Gantt) A class name for the data label. Particularly in styled mode, this can be used to give each series' or point's data label unique styling. In addition to this option, a default color class name is added so that we can give the labels a contrast text shadow.
final
- color → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) This options is deprecated. Use style.color instead.
final
- crop → bool?
-
(Highcharts, Highstock, Highmaps, Gantt) Whether to hide data labels that are outside the plot area. By default, the data label is moved inside the plot area according to the overflow option.
final
- defer → bool?
-
(Highcharts, Highstock, Gantt) Whether to defer displaying the data labels until the initial series animation has finished. Setting to
falserenders the data label immediately. If set totrueinherits the defer time set in plotOptions.series.animation.final - distance → num?
-
(Highcharts, Highstock, Gantt) The distance of the data label from the data point. Note that the
paddingsetting also affects the rendered distance, but is not visible unless the data label has a border or background.final - enabled → bool?
-
(Highcharts, Highstock, Highmaps, Gantt) Enable or disable the data labels.
final
- filter → HCDataLabelsFilterOptionsObject?
-
(Highcharts, Highstock, Highmaps, Gantt) A declarative filter to control of which data labels to display. The declarative filter is designed for use when callback functions are not available, like when the chart options require a pure JSON structure or for use with graphical editors. For programmati
final
- format → String?
-
(Highcharts, Highstock, Highmaps, Gantt) A format string for the data label. Available variables are the same as for
formatter.final - hashCode → int
-
The hash code for this object.
no setterinherited
- inside → bool?
-
(Highcharts, Highstock, Highmaps, Gantt) For points with an extent, like columns or map areas, whether to align the data label inside the box or to the actual value point. Defaults to
falsein most cases,truein stacked columns.final - labelrank → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The rank for this point's data label in case of collision. If two data labels are about to overlap, only the one with the highest
labelrankwill be drawn.final - nullFormat → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) Format for points with the value of null. Works analogously to format.
nullFormatcan be applied only to series which support displaying null points.heatmapandtilemapsupportsnullFormatby default while the following series requires [#series.nullIfinal - overflow → String?
-
(Highcharts, Highstock, Highmaps, Gantt) How to handle data labels that flow outside the plot area. The default is
"justify", which aligns them inside the plot area. For columns and bars, this means it will be moved inside the bar. To display data labels outside the plot area, setcropto `falsefinal - padding → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) When either the
borderWidthor thebackgroundColoris set, this is the padding within the box.final - position → String?
-
(Highcharts, Highstock, Highmaps, Gantt) Aligns data labels relative to points. If
centeralignment is not possible, it defaults toright.final - rotation → num?
-
(Highcharts, Highstock, Highmaps, Gantt) Text rotation in degrees. Note that due to a more complex structure, backgrounds, borders and padding will be lost on a rotated data label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) The shadow of the box. Works best with
borderWidthorbackgroundColor. Since 2.3 the shadow can be an object configuration containingcolor,offsetX,offsetY,opacityandwidth.final - shape → String?
-
(Highcharts, Highstock, Highmaps, Gantt) The name of a symbol to use for the border around the label. Symbols are predefined functions on the Renderer object.
final
- style → HCCSSObject?
-
(Highcharts, Highstock, Highmaps, Gantt) Styles for the label. The default
colorsetting is"contrast", which is a pseudo color that Highcharts picks up and applies the maximum contrast to the underlying point item, for example the bar in a bar chart.final - textPath → HCDataLabelsTextPathOptionsObject?
-
(Highcharts, Highstock, Highmaps, Gantt) Options for a label text which should follow marker's shape. Border and background are disabled for a label that follows a path.
final
- useHTML → bool?
-
(Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render the labels.
final
- verticalAlign → String?
-
(Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of a data label. Can be one of
top,middleorbottom. The default value depends on the data, for instance in a column chart, the label is above positive values and below negative values.final - x → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The x position offset of the label relative to the point in pixels.
final
- y → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The y position offset of the label relative to the point in pixels.
final
- zIndex → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The z index of the data labels group. Does not apply below series level options.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited