includeInDataExport property

bool? includeInDataExport
final

(Highstock) When set to false will prevent the series data from being included in any form of data export.

Implementation

final bool? includeInDataExport;