HCPlotTiledwebmapProviderOptions class

(Highmaps) Provider options for the series.

Implemented types

Constructors

HCPlotTiledwebmapProviderOptions({String? apiKey, String? subdomain, String? theme, String? type, String? url})
const

Properties

apiKey String?
(Highmaps) API key for providers that require using one.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subdomain String?
(Highmaps) Subdomain required by each provider. Check the providers documentation for available subdomains.
final
theme String?
(Highmaps) Set a tiles theme. Check the providers documentation for official list of available themes.
final
type String?
(Highmaps) Provider type to pull data (tiles) from.
final
url String?
(Highmaps) Custom URL for providers not specified in providers type. Available variables to use in URL are: {x}, {y}, {z} or {zoom}. Remember to always specify a projection, when using a custom URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited