HCPlotTilemapOptions class

(Highcharts, Highmaps) A tilemap series is a type of heatmap where the tile shapes are configurable.

Implemented types

Constructors

HCPlotTilemapOptions({HCSeriesAccessibilityOptionsObject? accessibility, bool? allowPointSelect, bool? animation, dynamic borderColor, num? borderRadius, num? borderWidth, String? className, bool? clip, dynamic color, dynamic colorAxis, num? colorIndex, String? colorKey, num? colsize, bool? crisp, String? cursor, HCDictionary? custom, dynamic dataLabels, HCDataMappingOptionsObject? dataMapping, String? description, bool? enableMouseTracking, HCSeriesEventsOptionsObject? events, num? gapSize, String? gapUnit, bool? inactiveOtherPoints, bool? includeInDataExport, bool? interpolation, List<String>? keys, HCSeriesLabelOptionsObject? label, String? legendSymbol, String? linkedTo, dynamic marker, dynamic negativeColor, dynamic nullColor, bool? nullInteraction, dynamic onPoint, num? opacity, HCPlotSeriesPointOptions? point, dynamic pointDescriptionFormat, dynamic pointDescriptionFormatter, num? pointPadding, bool? relativeXValue, num? rowsize, bool? selected, bool? showCheckbox, bool? showInLegend, bool? skipKeyboardNavigation, HCSeriesSonificationOptions? sonification, HCSeriesStatesOptionsObject? states, bool? stickyTracking, String? tileShape, HCSeriesTooltipOptionsObject? tooltip, num? turboThreshold, bool? visible, num? zIndex, String? zoneAxis, List<HCSeriesZonesOptionsObject>? zones, bool? zoomEnabled})
const

Properties

accessibility HCSeriesAccessibilityOptionsObject?
(Highcharts, Highmaps) Accessibility options for a series.
final
allowPointSelect bool?
(Highcharts, Highmaps) Allow this series' points to be selected by clicking on the graphic (columns, point markers, pie slices, map areas etc).
final
animation bool?
(Highcharts, Highmaps) Animation is disabled by default on the heatmap series.
final
borderColor → dynamic
(Highmaps) The border color of the map areas.
final
borderRadius num?
(Highcharts, Highmaps) The border radius for each heatmap item. The border's color and width can be set in marker options.
final
borderWidth num?
(Highmaps) The border width for each heatmap item.
final
className String?
(Highcharts, Highmaps) An additional class name to apply to the series' graphical elements. This option does not replace default class names of the graphical element. Changes to the series' color will also be reflected in a chart's legend and tooltip.
final
clip bool?
(Highcharts, Highmaps) Disable this option to allow series rendering in the whole plotting area.
final
color → dynamic
(Highcharts) The main color of the series. In heat maps this color is rarely used, as we mostly use the color to denote the value of each point. Unless options are set in the colorAxis, the default value is pulled from the options.colors array.
final
colorAxis → dynamic
(Highcharts, Highstock, Highmaps) When using dual or multiple color axes, this number defines which colorAxis the particular series is connected to. It refers to either the axis id or the index of the axis in the colorAxis array, with 0 being the first. Set this option to false to prevent a series f
final
colorIndex num?
(Highcharts, Highmaps) Styled mode only. A specific color index to use for the series, so its graphic representations are given the class name highcharts-color-{n}.
final
colorKey String?
(Highcharts, Highstock, Highmaps) Determines what data value should be used to calculate point color if colorAxis is used. Requires to set min and max if some custom point property is used or if approximation for data grouping is set to 'sum'.
final
colsize num?
(Highcharts, Highmaps) The column size - how many X axis units each column in the tilemap should span. Works as in Heatmaps.
final
crisp bool?
(Highcharts, Highstock, Gantt) When true, each point or column edge is rounded to its nearest pixel in order to render sharp on screen. In some cases, when there are a lot of densely packed columns, this leads to visible difference in column widths or distance between columns. In these cases, settin
final
cursor String?
(Highcharts, Highmaps) You can set the cursor to "pointer" if you have click events attached to the series, to signal to the user that the points and lines can be clicked.
final
custom HCDictionary?
(Highcharts, Highmaps) A reserved subspace to store options and values for customized functionality. Here you can add additional data for your own event callbacks and formatter callbacks.
final
dataLabels → dynamic
(Highcharts, Highstock, Highmaps, Gantt) Options for the series data labels, appearing next to each data point.
final
dataMapping HCDataMappingOptionsObject?
(Highcharts, Highmaps) The mapping between the data table and the series data points. This is used in conjunction with the dataTable option (on chart or series level) to map columns from the data table to the properties of the data points. The keys of the dataMapping object correspond to the pro
final
description String?
(Highcharts, Highmaps) Deprecated. Use plotOptions.series.accessibility.description instead.
final
enableMouseTracking bool?
(Highcharts, Highmaps) Enable or disable the mouse tracking for a specific series. This includes point tooltips and click events on graphs and points. For large datasets it improves performance.
final
events HCSeriesEventsOptionsObject?
(Highcharts, Highmaps) General event handlers for the series items. These event hooks can also be attached to the series at run time using the Highcharts.addEvent function.
final
gapSize num?
(Highcharts, Highstock) Defines when to display a gap in the graph, together with the gapUnit option.
final
gapUnit String?
(Highcharts, Highstock) Together with gapSize, this option defines where to draw gaps in the graph.
final
hashCode int
The hash code for this object.
no setterinherited
inactiveOtherPoints bool?
(Highcharts, Highmaps) Highlight only the hovered point and fade the remaining points.
final
includeInDataExport bool?
(Highcharts, Highmaps) When set to false will prevent the series data from being included in any form of data export.
final
interpolation bool?
(Highcharts, Highmaps) Make the heatmap render its data points as an interpolated image.
final
keys List<String>?
(Highcharts, Highmaps) An array specifying which option maps to which key in the data point array. This makes it convenient to work with unstructured data arrays from different sources.
final
label HCSeriesLabelOptionsObject?
(Highcharts, Highstock, Gantt) Series labels are placed as close to the series as possible in a natural way, seeking to avoid other series. The goal of this feature is to make the chart more easily readable, like if a human designer placed the labels in the optimal position.
final
legendSymbol String?
(Highcharts, Highmaps) What type of legend symbol to render for this series. Can be one of areaMarker, lineMarker or rectangle.
final
linkedTo String?
(Highcharts, Highstock, Gantt) The id of another series to link to. Additionally, the value can be ":previous" to link to the previous series. When two series are linked, only the first one appears in the legend. Toggling the visibility of this also toggles the linked series.
final
marker → dynamic
final
negativeColor → dynamic
(Highcharts, Highmaps) The color for the parts of the graph or points that are below the threshold. Note that zones takes precedence over the negative color. Using negativeColor is equivalent to applying a zone with value of 0.
final
nullColor → dynamic
(Highcharts, Highmaps) The color applied to null points. In styled mode, a general CSS class is applied instead.
final
nullInteraction bool?
(Highcharts, Highstock) Whether or not data-points with the value of null should be interactive. When this is set to true, tooltips may highlight these points, and this option also enables keyboard navigation for such points. Format options for such points include nullFormat and `nullFormatter
final
onPoint → dynamic
(Highcharts, Highmaps) Options for the Series on point feature. Only pie and sunburst series are supported at this moment.
final
opacity num?
(Highcharts, Highmaps) Opacity of a series parts: line, fill (e.g. area) and dataLabels.
final
point HCPlotSeriesPointOptions?
(Highcharts, Highmaps) Properties for each single point.
final
pointDescriptionFormat → dynamic
(Highcharts, Highmaps) Deprecated. Use series.accessibility.point.descriptionFormat instead.
final
pointDescriptionFormatter → dynamic
(Highcharts, Highmaps) Deprecated. Use series.accessibility.point.descriptionFormatter instead.
final
pointPadding num?
(Highcharts, Highmaps) The padding between points in the tilemap.
final
relativeXValue bool?
(Highcharts, Highstock) When true, X values in the data set are relative to the current pointStart, pointInterval and pointIntervalUnit settings. This allows compression of the data for datasets with irregular X values.
final
rowsize num?
(Highcharts, Highmaps) The row size - how many Y axis units each tilemap row should span. Analogous to colsize.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool?
(Highcharts, Highmaps) Whether to select the series initially. If showCheckbox is true, the checkbox next to the series name in the legend will be checked for a selected series.
final
showCheckbox bool?
(Highcharts, Highmaps) If true, a checkbox is displayed next to the legend item to allow selecting the series. The state of the checkbox is determined by the selected option.
final
showInLegend bool?
(Highcharts, Highmaps) Whether to display this particular series or series type in the legend. Standalone series are shown in legend by default, and linked series are not. Since v7.2.0 it is possible to show series that use colorAxis by setting this option to true.
final
skipKeyboardNavigation bool?
(Highcharts, Highmaps) Deprecated. Use series.accessibility.keyboardNavigation instead.
final
sonification HCSeriesSonificationOptions?
(Highcharts, Highmaps) Sonification/audio chart options for a series.
final
states HCSeriesStatesOptionsObject?
(Highcharts, Highmaps) A collection of options for different series states.
final
stickyTracking bool?
(Highcharts, Highstock, Highmaps) Sticky tracking of mouse events. When true, the mouseOut event on a series isn't triggered until the mouse moves over another series, or out of the plot area. When false, the mouseOut event on a series is triggered when the mouse leaves the area around the serie
final
tileShape String?
(Highcharts, Highmaps) The shape of the tiles in the tilemap. Possible values are hexagon, circle, diamond, and square.
final
tooltip HCSeriesTooltipOptionsObject?
(Highcharts, Highstock, Highmaps) A configuration object for the tooltip rendering of each single series. Properties are inherited from tooltip. Overridable properties are headerFormat, pointFormat, yDecimals, xDateFormat, yPrefix and ySuffix. Unlike other series, in a scatter plot the s
final
turboThreshold num?
(Highcharts, Highstock, Gantt) When a series contains a data array that is longer than this, the Series class looks for data configurations of plain numbers or arrays of numbers. The first and last valid points are checked. If found, the rest of the data is assumed to be the same. This saves expen
final
visible bool?
(Highcharts, Highmaps) Set the initial visibility of the series.
final
zIndex num?
(Highmaps) Define the z index of the series.
final
zoneAxis String?
(Highcharts, Highstock) Defines the Axis on which the zones are applied.
final
zones List<HCSeriesZonesOptionsObject>?
(Highcharts, Highstock) An array defining zones within a series. Zones can be applied to the X axis, Y axis or Z axis for bubbles, according to the zoneAxis option. The zone definitions have to be in ascending order regarding to the value.
final
zoomEnabled bool?
(Highcharts, Highmaps) Whether to zoom non-cartesian series. If chart.zooming is set, the option allows to disable zooming on an individual non-cartesian series. By default zooming is enabled for all series.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited