turboThreshold property
(Highcharts, Highstock, Gantt) When a series contains a data array that is longer than this, the Series class looks for data configurations of plain numbers or arrays of numbers. The first and last valid points are checked. If found, the rest of the data is assumed to be the same. This saves expen
Implementation
final num? turboThreshold;