HCPlotTimelineDataLabelsStyleOptions class

(Highcharts, Highstock, Highmaps, Gantt) Styles for the label. The default color setting is "contrast", which is a pseudo color that Highcharts picks up and applies the maximum contrast to the underlying point item, for example the bar in a bar chart.

Implemented types

Constructors

HCPlotTimelineDataLabelsStyleOptions({num? fontSize, String? fontWeight, String? textAlign, String? textOutline})
const

Properties

fontSize num?
final
fontWeight String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlign String?
final
textOutline String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited