HCPlotTreegraphCollapseButtonOptions class

(Highcharts) Options applied to collapse Button. The collapse button is the small button which indicates, that the node is collapsable.

Implemented types

Constructors

HCPlotTreegraphCollapseButtonOptions({bool? enabled, num? height, num? lineWidth, bool? onlyOnHover, String? shape, HCPlotTreegraphCollapseButtonStyleOptions? style, num? width, num? x, num? y})
const

Properties

enabled bool?
(Highcharts) Whether the button should be visible.
final
hashCode int
The hash code for this object.
no setterinherited
height num?
(Highcharts) Height of the button.
final
lineWidth num?
(Highcharts) The line width of the button in pixels
final
onlyOnHover bool?
(Highcharts) Whether the button should be visible only when the node is hovered. When set to true, the button is hidden for nodes, which are not collapsed, and shown for the collapsed ones.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape String?
(Highcharts) The symbol of the collapse button.
final
style HCPlotTreegraphCollapseButtonStyleOptions?
(Highcharts) CSS styles for the collapse button.
final
width num?
(Highcharts) Width of the button.
final
x num?
(Highcharts) Offset of the button in the x direction.
final
y num?
(Highcharts) Offset of the button in the y direction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited