HCPlotVbpVolumeDivisionStylesOptions class

Implemented types

Constructors

HCPlotVbpVolumeDivisionStylesOptions({String? negativeColor, String? positiveColor})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
negativeColor String?
(Highstock) Color of negative volume bars.
final
positiveColor String?
(Highstock) Color of positive volume bars.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited