HCPlotVectorClusterLayoutAlgorithmOptions class

(Highcharts, Highmaps) Options for layout algorithm. Inside there are options to change the type of the algorithm, gridSize, distance or iterations.

Implemented types

Constructors

HCPlotVectorClusterLayoutAlgorithmOptions({dynamic distance, dynamic gridSize, num? iterations, num? kmeansThreshold, dynamic type})
const

Properties

distance → dynamic
(Highcharts, Highmaps) When type is set to kmeans, distance is a maximum distance between point and cluster center so that this point will be inside the cluster. The distance is either a number defining pixels or a percentage defining a percentage of the plot area width.
final
gridSize → dynamic
(Highcharts, Highmaps) When type is set to the grid, gridSize is a size of a grid square element either as a number defining pixels, or a percentage defining a percentage of the plot area width.
final
hashCode int
The hash code for this object.
no setterinherited
iterations num?
(Highcharts, Highmaps) When type is set to kmeans, iterations are the number of iterations that this algorithm will be repeated to find clusters positions.
final
kmeansThreshold num?
(Highcharts, Highmaps) When type is set to undefined and there are more visible points than the kmeansThreshold the grid algorithm is used to find clusters, otherwise kmeans. It ensures good performance on large datasets and better clusters arrangement after the zoom.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → dynamic
(Highcharts, Highmaps) Type of the algorithm used to combine points into a cluster. There are three available algorithms:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited