HCPlotWilliamsrOnPointPositionOptions class
(Highstock) Options allowing to set a position and an offset of the series in the Series on point feature.
- Implemented types
Constructors
- HCPlotWilliamsrOnPointPositionOptions({num? offsetX, num? offsetY, num? x, num? y})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- offsetX → num?
-
(Highstock) Series center offset from the original x position. If defined, the connector line is drawn connecting original position with new position.
final
- offsetY → num?
-
(Highstock) Series center offset from the original y position. If defined, the connector line is drawn from original position to a new position.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x → num?
-
(Highstock) X position of the series center. By default, the series is displayed on the point that it is connected to.
final
- y → num?
-
(Highstock) Y position of the series center. By default, the series is displayed on the point that it is connected to.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited