tooltip property

(Highcharts) A configuration object for the tooltip rendering of each single series. Properties are inherited from tooltip, but only the following properties can be defined on a series level.

Implementation

final HCSeriesTooltipOptionsObject? tooltip;