upColor property
dynamic
upColor
final
(Highstock) The fill color of the candlestick when the current close is higher than the previous one.
Implementation
final dynamic upColor;
(Highstock) The fill color of the candlestick when the current close is higher than the previous one.
final dynamic upColor;