inactiveOtherPoints property
(Highstock) Highlight only the hovered point and fade the remaining points.
Implementation
final bool? inactiveOtherPoints;
(Highstock) Highlight only the hovered point and fade the remaining points.
final bool? inactiveOtherPoints;