HCSeriesItemOptions class
(Highcharts) An item series. If the type option is not specified, it is inherited from chart.type.
- Implemented types
Constructors
-
HCSeriesItemOptions({HCSeriesAccessibilityOptionsObject? accessibility, bool? allowPointSelect, dynamic animation, dynamic borderRadius, dynamic center, String? className, bool? clip, dynamic color, dynamic colorAxis, num? colorIndex, String? colorKey, List? colors, bool? crisp, String? cursor, HCDictionary? custom, dynamic dataLabels, HCDataMappingOptionsObject? dataMapping, String? description, bool? enableMouseTracking, num? endAngle, HCSeriesEventsOptionsObject? events, dynamic fillColor, num? gapSize, String? gapUnit, bool? ignoreHiddenPoint, bool? inactiveOtherPoints, bool? includeInDataExport, dynamic innerSize, num? itemPadding, List<
String> ? keys, String? layout, String? legendSymbol, dynamic legendSymbolColor, HCPointMarkerOptionsObject? marker, dynamic minSize, bool? nullInteraction, dynamic onPoint, num? opacity, HCPlotSeriesPointOptions? point, dynamic pointDescriptionFormat, dynamic pointDescriptionFormatter, bool? relativeXValue, num? rows, bool? selected, bool? showCheckbox, bool? showInLegend, dynamic size, HCSeriesSonificationOptions? sonification, num? startAngle, HCSeriesStatesOptionsObject? states, bool? stickyTracking, num? thickness, HCSeriesTooltipOptionsObject? tooltip, bool? visible, bool? zoomEnabled, String? id, num? index, num? legendIndex, dynamic mapData, String? name, dynamic stack, String? type, dynamic xAxis, dynamic yAxis, num? zIndex, List? data, dynamic dataParser, dynamic dataURL}) -
const
Properties
- accessibility → HCSeriesAccessibilityOptionsObject?
-
(Highcharts) Accessibility options for a series.
final
- allowPointSelect → bool?
-
(Highcharts) Allow this series' points to be selected by clicking on the graphic (columns, point markers, pie slices, map areas etc).
final
- animation → dynamic
-
(Highcharts) Enable or disable the initial animation when a series is displayed. The animation can also be set as a configuration object. Please note that this option only applies to the initial animation of the series itself. For other animations, see chart.animation and the animation parameter und
final
- borderRadius → dynamic
-
(Highcharts) The corner radius of the border surrounding each slice. A number signifies pixels. A percentage string, like for example
50%, signifies a size relative to the radius and the inner radius.final - center → dynamic
-
(Highcharts, Highmaps) The center of the pie chart relative to the plot area. Can be percentages or pixel values. The default behavior (as of 3.0) is to center the pie so that all slices and data labels are within the plot area. As a consequence, the pie may actually jump around in a chart with dyna
final
- className → String?
-
(Highcharts) An additional class name to apply to the series' graphical elements. This option does not replace default class names of the graphical element. Changes to the series' color will also be reflected in a chart's legend and tooltip.
final
- clip → bool?
-
(Highcharts) Disable this option to allow series rendering in the whole plotting area.
final
- color → dynamic
-
(Highcharts) The color of the pie series. A pie series is represented as an empty circle if the total sum of its values is 0. Use this property to define the color of its border.
final
- colorAxis → dynamic
-
(Highcharts, Highstock, Highmaps) When using dual or multiple color axes, this number defines which colorAxis the particular series is connected to. It refers to either the axis id or the index of the axis in the colorAxis array, with 0 being the first. Set this option to false to prevent a series f
final
- colorIndex → num?
-
(Highcharts) Styled mode only. A specific color index to use for the series, so its graphic representations are given the class name
highcharts-color-{n}.final - colorKey → String?
-
(Highcharts, Highstock, Highmaps) Determines what data value should be used to calculate point color if
colorAxisis used. Requires to setminandmaxif some custom point property is used or if approximation for data grouping is set to'sum'.final - colors → List?
-
(Highcharts, Highmaps) A series specific or series type specific color set to use instead of the global colors.
final
- crisp → bool?
-
(Highcharts, Highstock, Gantt) When true, each point or column edge is rounded to its nearest pixel in order to render sharp on screen. In some cases, when there are a lot of densely packed columns, this leads to visible difference in column widths or distance between columns. In these cases, settin
final
- cursor → String?
-
(Highcharts) You can set the cursor to "pointer" if you have click events attached to the series, to signal to the user that the points and lines can be clicked.
final
- custom → HCDictionary?
-
(Highcharts) A reserved subspace to store options and values for customized functionality. Here you can add additional data for your own event callbacks and formatter callbacks.
final
- data → List?
-
(Highcharts) An array of data points for the series. For the
itemseries type, points can be given in the following ways:final - dataLabels → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) Options for the series data labels, appearing next to each data point.
final
- dataMapping → HCDataMappingOptionsObject?
-
(Highcharts) The mapping between the data table and the series data points. This is used in conjunction with the
dataTableoption (on chart or series level) to map columns from the data table to the properties of the data points. The keys of thedataMappingobject correspond to the properties offinal - dataParser → dynamic
-
Not available
final
- dataURL → dynamic
-
Not available
final
- description → String?
-
(Highcharts) Deprecated. Use plotOptions.series.accessibility.description instead.
final
- enableMouseTracking → bool?
-
(Highcharts) Enable or disable the mouse tracking for a specific series. This includes point tooltips and click events on graphs and points. For large datasets it improves performance.
final
- endAngle → num?
-
(Highcharts, Highmaps) In circular view, the end angle of the item layout, in degrees where 0 is up.
final
- events → HCSeriesEventsOptionsObject?
-
(Highcharts) General event handlers for the series items. These event hooks can also be attached to the series at run time using the
Highcharts.addEventfunction.final - fillColor → dynamic
-
(Highcharts) If the total sum of the pie's values is 0, the series is represented as an empty circle . The
fillColoroption defines the color of that circle. Use pie.borderWidth to set the border thickness.final - gapSize → num?
-
(Highcharts, Highstock) Defines when to display a gap in the graph, together with the gapUnit option.
final
- gapUnit → String?
-
(Highcharts, Highstock) Together with gapSize, this option defines where to draw gaps in the graph.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
(Highcharts, Highstock, Highmaps, Gantt) An id for the series. This can be used after render time to get a pointer to the series object through
chart.get().final - ignoreHiddenPoint → bool?
-
(Highcharts, Highmaps) Equivalent to chart.ignoreHiddenSeries, this option tells whether the series shall be redrawn as if the hidden point were
null.final - inactiveOtherPoints → bool?
-
(Highcharts) Highlight only the hovered point and fade the remaining points.
final
- includeInDataExport → bool?
-
(Highcharts) When set to
falsewill prevent the series data from being included in any form of data export.final - index → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The index of the series in the chart, affecting the internal index in the
chart.seriesarray, the visible Z index as well as the order in the legend.final - innerSize → dynamic
-
(Highcharts, Highmaps) In circular view, the size of the inner diameter of the circle. Can be a percentage or pixel value. Percentages are relative to the outer perimeter. Pixel values are given as integers.
final
- itemPadding → num?
-
(Highcharts) The padding between the items, given in relative size where the size of the item is 1.
final
-
keys
→ List<
String> ? -
(Highcharts) An array specifying which option maps to which key in the data point array. This makes it convenient to work with unstructured data arrays from different sources.
final
- layout → String?
-
(Highcharts) The layout of the items in rectangular view. Can be either
horizontalorvertical.final - legendIndex → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The sequential index of the series in the legend.
final
- legendSymbol → String?
-
(Highcharts) What type of legend symbol to render for this series. Can be one of
areaMarker,lineMarkerorrectangle.final - legendSymbolColor → dynamic
-
(Highcharts, Highstock, Highmaps) Defines the color of the legend symbol for this series. Defaults to undefined, in which case the series color is used. Does not work with styled mode.
final
- mapData → dynamic
-
(Highmaps) An array of objects containing a
geometryorpathdefinition and optionally additional properties to join in thedataas per thejoinByoption. GeoJSON and TopoJSON structures can also be passed directly intomapData.final - marker → HCPointMarkerOptionsObject?
-
(Highcharts) Options for the point markers of line and scatter-like series. Properties like
fillColor,lineColorandlineWidthdefine the visual appearance of the markers. Thesymboloption defines the shape. Other series types, like column series, don't have markers, but have visual optionsfinal - minSize → dynamic
-
(Highcharts, Highmaps) The minimum size for a pie in response to auto margins. The pie will try to shrink to make room for data labels in side the plot area, but only to this size.
final
- name → String?
-
(Highcharts, Highstock, Highmaps, Gantt) The name of the series as shown in the legend, tooltip etc. If a
dataTableanddataMappingare used, the name defaults to the id of the primary data table column. Otherwise, it defaults to "Series {n}", where n is the index of the series, starting at 1.final - nullInteraction → bool?
-
(Highcharts, Highstock) Whether or not data-points with the value of
nullshould be interactive. When this is set totrue, tooltips may highlight these points, and this option also enables keyboard navigation for such points. Format options for such points includenullFormatand `nullFormatterfinal - onPoint → dynamic
-
(Highcharts) Options for the Series on point feature. Only
pieandsunburstseries are supported at this moment.final - opacity → num?
-
(Highcharts) Opacity of a series parts: line, fill (e.g. area) and dataLabels.
final
- point → HCPlotSeriesPointOptions?
-
(Highcharts) Properties for each single point.
final
- pointDescriptionFormat → dynamic
-
(Highcharts) Deprecated. Use series.accessibility.point.descriptionFormat instead.
final
- pointDescriptionFormatter → dynamic
-
(Highcharts) Deprecated. Use series.accessibility.point.descriptionFormatter instead.
final
- relativeXValue → bool?
-
(Highcharts, Highstock) When true, X values in the data set are relative to the current
pointStart,pointIntervalandpointIntervalUnitsettings. This allows compression of the data for datasets with irregular X values.final - rows → num?
-
(Highcharts) The number of rows to display in the rectangular or circular view. If the
innerSizeis set, it will be overridden by therowssetting.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool?
-
(Highcharts) Whether to select the series initially. If
showCheckboxis true, the checkbox next to the series name in the legend will be checked for a selected series.final - showCheckbox → bool?
-
(Highcharts) If true, a checkbox is displayed next to the legend item to allow selecting the series. The state of the checkbox is determined by the
selectedoption.final - showInLegend → bool?
-
(Highcharts, Highmaps) Whether to display this particular series or series type in the legend. Since 2.1, pies are not shown in the legend by default.
final
- size → dynamic
-
(Highcharts, Highmaps) The diameter of the pie relative to the plot area. Can be a percentage or pixel value. Pixel values are given as integers. The default behavior (as of 3.0) is to scale to the plot area and give room for data labels within the plot area. slicedOffset is also included in the def
final
-
(Highcharts) Deprecated. Use series.accessibility.keyboardNavigation instead.
final
- sonification → HCSeriesSonificationOptions?
-
(Highcharts) Sonification/audio chart options for a series.
final
- stack → dynamic
-
Not available
final
- startAngle → num?
-
(Highcharts, Highmaps) In circular view, the start angle of the item layout, in degrees where 0 is up.
final
- states → HCSeriesStatesOptionsObject?
-
(Highcharts) A collection of options for different series states.
final
- stickyTracking → bool?
-
(Highcharts, Highmaps) Sticky tracking of mouse events. When true, the
mouseOutevent on a series isn't triggered until the mouse moves over another series, or out of the plot area. When false, themouseOutevent on a series is triggered when the mouse leaves the area around the series' graph orfinal - thickness → num?
-
(Highcharts) Thickness describing the ring size for a donut type chart, overriding innerSize.
final
- tooltip → HCSeriesTooltipOptionsObject?
-
(Highcharts) A configuration object for the tooltip rendering of each single series. Properties are inherited from tooltip, but only the following properties can be defined on a series level.
final
- type → String?
-
(Highcharts, Highstock, Highmaps, Gantt) This property is only in TypeScript non-optional and might be
undefinedin series objects from unknown sources.final - visible → bool?
-
(Highcharts) Set the initial visibility of the series.
final
- xAxis → dynamic
-
Not available
final
- yAxis → dynamic
-
Not available
final
- zIndex → num?
-
(Highcharts, Highstock) Define the visual z index of the series.
final
- zoomEnabled → bool?
-
(Highcharts) Whether to zoom non-cartesian series. If
chart.zoomingis set, the option allows to disable zooming on an individual non-cartesian series. By default zooming is enabled for all series.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited