mapData property

dynamic mapData
final

(Highmaps) An array of objects containing a geometry or path definition and optionally additional properties to join in the data as per the joinBy option. GeoJSON and TopoJSON structures can also be passed directly into mapData.

Implementation

final dynamic mapData;