HCSeriesMaplineOptions class

(Highmaps) A mapline series. If the type option is not specified, it is inherited from chart.type.

Implemented types

Constructors

HCSeriesMaplineOptions({HCSeriesAccessibilityOptionsObject? accessibility, bool? affectsMapView, bool? allAreas, bool? allowPointSelect, bool? animation, num? animationLimit, dynamic borderColor, num? borderWidth, String? className, bool? clip, dynamic color, dynamic colorAxis, bool? colorByPoint, num? colorIndex, String? colorKey, List? colors, String? cursor, HCDictionary? custom, String? dashStyle, dynamic dataLabels, HCDataMappingOptionsObject? dataMapping, String? description, bool? enableMouseTracking, HCSeriesEventsOptionsObject? events, dynamic fillColor, String? findNearestPointBy, bool? inactiveOtherPoints, bool? includeInDataExport, dynamic joinBy, List<String>? keys, String? legendSymbol, String? linecap, num? lineWidth, dynamic negativeColor, dynamic nullColor, dynamic onPoint, num? opacity, HCPlotSeriesPointOptions? point, dynamic pointDescriptionFormat, dynamic pointDescriptionFormatter, bool? selected, bool? showCheckbox, bool? showInLegend, bool? skipKeyboardNavigation, HCSeriesSonificationOptions? sonification, HCSeriesStatesOptionsObject? states, bool? stickyTracking, HCSeriesTooltipOptionsObject? tooltip, bool? visible, num? zIndex, bool? zoomEnabled, String? id, num? index, num? legendIndex, dynamic mapData, String? name, dynamic stack, String? type, dynamic xAxis, dynamic yAxis, List? data, dynamic dataParser, dynamic dataURL})
const

Properties

accessibility HCSeriesAccessibilityOptionsObject?
(Highmaps) Accessibility options for a series.
final
affectsMapView bool?
(Highmaps) Whether the MapView takes this series into account when computing the default zoom and center of the map.
final
allAreas bool?
(Highmaps) Whether all areas of the map defined in mapData should be rendered. If true, areas which don't correspond to a data point, are rendered as null points. If false, those areas are skipped.
final
allowPointSelect bool?
(Highmaps) Allow this series' points to be selected by clicking on the graphic (columns, point markers, pie slices, map areas etc).
final
animation bool?
(Highmaps) Enable or disable the initial animation when a series is displayed. The animation can also be set as a configuration object. Please note that this option only applies to the initial animation of the series itself. For other animations, see chart.animation and the animation parameter under
final
animationLimit num?
(Highmaps) For some series, there is a limit that shuts down animation by default when the total number of points in the chart is too high. For example, for a column chart and its derivatives, animation does not run if there is more than 250 points totally. To disable this cap, set animationLimit
final
borderColor → dynamic
(Highmaps) The border color of the map areas.
final
borderWidth num?
(Highmaps) The border width of each map area.
final
className String?
(Highmaps) An additional class name to apply to the series' graphical elements. This option does not replace default class names of the graphical element. Changes to the series' color will also be reflected in a chart's legend and tooltip.
final
clip bool?
(Highmaps) Disable this option to allow series rendering in the whole plotting area.
final
color → dynamic
(Highmaps) The main color of the series. In line type series it applies to the line and the point markers unless otherwise specified. In bar type series it applies to the bars unless a color is specified per point. The default value is pulled from the options.colors array.
final
colorAxis → dynamic
(Highcharts, Highstock, Highmaps) When using dual or multiple color axes, this number defines which colorAxis the particular series is connected to. It refers to either the axis id or the index of the axis in the colorAxis array, with 0 being the first. Set this option to false to prevent a series f
final
colorByPoint bool?
(Highmaps) When using automatic point colors pulled from the global colors or series-specific plotOptions.map.colors collections, this option determines whether the chart should receive one color per series or one color per point.
final
colorIndex num?
(Highmaps) Styled mode only. A specific color index to use for the series, so its graphic representations are given the class name highcharts-color-{n}.
final
colorKey String?
(Highcharts, Highstock, Highmaps) Determines what data value should be used to calculate point color if colorAxis is used. Requires to set min and max if some custom point property is used or if approximation for data grouping is set to 'sum'.
final
colors List?
(Highmaps) A series specific or series type specific color set to apply instead of the global colors when colorByPoint is true.
final
cursor String?
(Highmaps) You can set the cursor to "pointer" if you have click events attached to the series, to signal to the user that the points and lines can be clicked.
final
custom HCDictionary?
(Highmaps) A reserved subspace to store options and values for customized functionality. Here you can add additional data for your own event callbacks and formatter callbacks.
final
dashStyle String?
(Highmaps) Name of the dash style to use for the graph, or for some series types the outline of each shape.
final
data List?
(Highmaps) An array of data points for the series. For the mapline series type, points can be given in the following ways:
final
dataLabels → dynamic
(Highcharts, Highstock, Highmaps, Gantt) Options for the series data labels, appearing next to each data point.
final
dataMapping HCDataMappingOptionsObject?
(Highmaps) The mapping between the data table and the series data points. This is used in conjunction with the dataTable option (on chart or series level) to map columns from the data table to the properties of the data points. The keys of the dataMapping object correspond to the properties of t
final
dataParser → dynamic
Not available
final
dataURL → dynamic
Not available
final
description String?
(Highmaps) Deprecated. Use plotOptions.series.accessibility.description instead.
final
enableMouseTracking bool?
(Highmaps) Enable or disable the mouse tracking for a specific series. This includes point tooltips and click events on graphs and points. For large datasets it improves performance.
final
events HCSeriesEventsOptionsObject?
(Highmaps) General event handlers for the series items. These event hooks can also be attached to the series at run time using the Highcharts.addEvent function.
final
fillColor → dynamic
(Highmaps) Fill color for the map line shapes
final
findNearestPointBy String?
(Highmaps) Determines whether the series should look for the nearest point in both dimensions or just the x-dimension when hovering the series. Defaults to 'xy' for scatter series and 'x' for most other series. If the data has duplicate x-values, it is recommended to set this to 'xy' to allow
final
hashCode int
The hash code for this object.
no setterinherited
id String?
(Highcharts, Highstock, Highmaps, Gantt) An id for the series. This can be used after render time to get a pointer to the series object through chart.get().
final
inactiveOtherPoints bool?
(Highmaps) Highlight only the hovered point and fade the remaining points.
final
includeInDataExport bool?
(Highmaps) When set to false will prevent the series data from being included in any form of data export.
final
index num?
(Highcharts, Highstock, Highmaps, Gantt) The index of the series in the chart, affecting the internal index in the chart.series array, the visible Z index as well as the order in the legend.
final
joinBy → dynamic
(Highmaps) What property to join the mapData to the value data. For example, if joinBy is "code", the mapData items with a specific code is merged into the data with the same code. For maps loaded from GeoJSON, the keys may be held in each point's properties object.
final
keys List<String>?
(Highmaps) An array specifying which option maps to which key in the data point array. This makes it convenient to work with unstructured data arrays from different sources.
final
legendIndex num?
(Highcharts, Highstock, Highmaps, Gantt) The sequential index of the series in the legend.
final
legendSymbol String?
(Highmaps) What type of legend symbol to render for this series. Can be one of areaMarker, lineMarker or rectangle.
final
linecap String?
(Highmaps) The line cap used for line ends and line joins on the graph.
final
lineWidth num?
(Highmaps) Pixel width of the mapline line.
final
mapData → dynamic
(Highmaps) An array of objects containing a geometry or path definition and optionally additional properties to join in the data as per the joinBy option. GeoJSON and TopoJSON structures can also be passed directly into mapData.
final
name String?
(Highcharts, Highstock, Highmaps, Gantt) The name of the series as shown in the legend, tooltip etc. If a dataTable and dataMapping are used, the name defaults to the id of the primary data table column. Otherwise, it defaults to "Series {n}", where n is the index of the series, starting at 1.
final
negativeColor → dynamic
(Highmaps) The color for the parts of the graph or points that are below the threshold. Note that zones takes precedence over the negative color. Using negativeColor is equivalent to applying a zone with value of 0.
final
nullColor → dynamic
(Highmaps) The color to apply to null points.
final
onPoint → dynamic
(Highmaps) Options for the Series on point feature. Only pie and sunburst series are supported at this moment.
final
opacity num?
(Highmaps) Opacity of a series parts: line, fill (e.g. area) and dataLabels.
final
point HCPlotSeriesPointOptions?
(Highmaps) Properties for each single point.
final
pointDescriptionFormat → dynamic
(Highmaps) Deprecated. Use series.accessibility.point.descriptionFormat instead.
final
pointDescriptionFormatter → dynamic
(Highmaps) Deprecated. Use series.accessibility.point.descriptionFormatter instead.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool?
(Highmaps) Whether to select the series initially. If showCheckbox is true, the checkbox next to the series name in the legend will be checked for a selected series.
final
showCheckbox bool?
(Highmaps) If true, a checkbox is displayed next to the legend item to allow selecting the series. The state of the checkbox is determined by the selected option.
final
showInLegend bool?
(Highmaps) Whether to display this particular series or series type in the legend. Standalone series are shown in legend by default, and linked series are not. Since v7.2.0 it is possible to show series that use colorAxis by setting this option to true.
final
skipKeyboardNavigation bool?
(Highmaps) Deprecated. Use series.accessibility.keyboardNavigation instead.
final
sonification HCSeriesSonificationOptions?
(Highmaps) Sonification/audio chart options for a series.
final
stack → dynamic
(Highcharts, Highstock) This option allows grouping series in a stacked chart. The stack option can be a string or anything else, as long as the grouped series' stack options match each other after conversion into a string.
final
states HCSeriesStatesOptionsObject?
(Highmaps) A collection of options for different series states.
final
stickyTracking bool?
(Highcharts, Highstock, Highmaps) Sticky tracking of mouse events. When true, the mouseOut event on a series isn't triggered until the mouse moves over another series, or out of the plot area. When false, the mouseOut event on a series is triggered when the mouse leaves the area around the serie
final
tooltip HCSeriesTooltipOptionsObject?
(Highcharts, Highstock, Highmaps) A configuration object for the tooltip rendering of each single series. Properties are inherited from tooltip. Overridable properties are headerFormat, pointFormat, yDecimals, xDateFormat, yPrefix and ySuffix. Unlike other series, in a scatter plot the s
final
type String?
(Highcharts, Highstock, Highmaps, Gantt) This property is only in TypeScript non-optional and might be undefined in series objects from unknown sources.
final
visible bool?
(Highmaps) Set the initial visibility of the series.
final
xAxis → dynamic
(Highcharts, Highstock) When using dual or multiple x axes, this number defines which xAxis the particular series is connected to. It refers to either the axis id or the index of the axis in the xAxis array, with 0 being the first.
final
yAxis → dynamic
(Highcharts, Highstock) When using dual or multiple y axes, this number defines which yAxis the particular series is connected to. It refers to either the axis id or the index of the axis in the yAxis array, with 0 being the first.
final
zIndex num?
(Highcharts, Highstock) Define the visual z index of the series.
final
zoomEnabled bool?
(Highmaps) Whether to zoom non-cartesian series. If chart.zooming is set, the option allows to disable zooming on an individual non-cartesian series. By default zooming is enabled for all series.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited