findNearestPointBy property

String? findNearestPointBy
final

(Highmaps) Determines whether the series should look for the nearest point in both dimensions or just the x-dimension when hovering the series. Defaults to 'xy' for scatter series and 'x' for most other series. If the data has duplicate x-values, it is recommended to set this to 'xy' to allow

Implementation

final String? findNearestPointBy;