joinBy property
dynamic
joinBy
final
(Highmaps) What property to join the mapData to the value data. For example, if joinBy is "code", the mapData items with a specific code is merged into the data with the same code. For maps loaded from GeoJSON, the keys may be held in each point's properties object.
Implementation
final dynamic joinBy;