colorByPoint property

bool? colorByPoint
final

(Highcharts, Highstock, Gantt) When using automatic point colors pulled from the global colors or series-specific plotOptions.column.colors collections, this option determines whether the chart should receive one color per series or one color per point.

Implementation

final bool? colorByPoint;