HCSeriesSunburstDataLabelsOptionsObject class
(Highcharts, Highstock, Highmaps, Gantt) Can set dataLabels on all points which lies on the same level.
- Implemented types
Constructors
- HCSeriesSunburstDataLabelsOptionsObject({String? alignTo, bool? allowOverlap, dynamic animation, dynamic backgroundColor, dynamic borderColor, num? borderRadius, num? borderWidth, String? className, dynamic color, dynamic connectorColor, num? connectorPadding, dynamic connectorShape, num? connectorWidth, String? crookDistance, bool? crop, bool? defer, dynamic distance, bool? enabled, HCDataLabelsFilterOptionsObject? filter, String? format, num? labelrank, dynamic nullFormat, String? overflow, dynamic padding, String? position, num? rotation, String? rotationMode, dynamic shadow, String? shape, bool? softConnector, dynamic style, HCDataLabelsTextPathOptionsObject? textPath, bool? useHTML, String? verticalAlign, num? x, num? y, num? zIndex})
-
const
Properties
- alignTo → String?
-
(Highcharts, Highmaps) Alignment method for data labels. Possible values are:
final
- allowOverlap → bool?
-
final
- animation → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) Enable or disable the initial animation when a series is displayed for the
dataLabels. The animation can also be set as a configuration object. Please note that this option only applies to the initial animation.final - backgroundColor → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) The background color or gradient for the data label. In addition to regular colors, there are two special setting for this option:
final
- borderColor → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) The border color for the data label. Setting it to
autowill use the point's color. Defaults toundefined.final - borderRadius → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The border radius in pixels for the data label.
final
- borderWidth → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The border width in pixels for the data label.
final
- className → String?
-
(Highcharts, Highstock, Highmaps, Gantt) A class name for the data label. Particularly in styled mode, this can be used to give each series' or point's data label unique styling. In addition to this option, a default color class name is added so that we can give the labels a contrast text shadow.
final
- color → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) This options is deprecated. Use style.color instead.
final
- connectorColor → dynamic
-
(Highcharts, Highmaps) The color of the line connecting the data label to the pie slice. The default color is the same as the point's color.
final
- connectorPadding → num?
-
(Highcharts, Highmaps) The distance from the data label to the connector. Note that data labels also have a default
padding, so in order for the connector to touch the text, thepaddingmust also be 0.final - connectorShape → dynamic
-
(Highcharts, Highmaps) Specifies the method that is used to generate the connector path. Highcharts provides 3 built-in connector shapes:
'crookedLine'(default since v11),'fixedOffset'and'straight'.final - connectorWidth → num?
-
(Highcharts, Highmaps) The width of the line connecting the data label to the pie slice.
final
- crookDistance → String?
-
(Highcharts, Highmaps) Works only if
connectorShapeis'crookedLine'. It defines how far from the vertical plot edge the connector path should be crooked. With the default,undefined, the crook is placed so that the horizontal line from the label intersects with the radial line extending throufinal - crop → bool?
-
(Highcharts, Highstock, Highmaps, Gantt) Whether to hide data labels that are outside the plot area. By default, the data label is moved inside the plot area according to the overflow option.
final
- defer → bool?
-
(Highcharts, Highstock, Gantt) Whether to defer displaying the data labels until the initial series animation has finished. Setting to
falserenders the data label immediately. If set totrueinherits the defer time set in plotOptions.series.animation.final - distance → dynamic
-
(Highcharts, Highmaps) The distance of the data label from the pie's edge. Negative numbers put the data label on top of the pie slices. Can also be defined as a percentage of pie's radius. Connectors are only shown for data labels outside the pie.
final
- enabled → bool?
-
(Highcharts, Highstock, Highmaps, Gantt) Enable or disable the data labels.
final
- filter → HCDataLabelsFilterOptionsObject?
-
(Highcharts, Highstock, Highmaps, Gantt) A declarative filter to control of which data labels to display. The declarative filter is designed for use when callback functions are not available, like when the chart options require a pure JSON structure or for use with graphical editors. For programmati
final
- format → String?
-
(Highcharts, Highstock, Highmaps, Gantt) A format string for the data label. Available variables are the same as for
formatter.final - hashCode → int
-
The hash code for this object.
no setterinherited
- labelrank → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The rank for this point's data label in case of collision. If two data labels are about to overlap, only the one with the highest
labelrankwill be drawn.final - nullFormat → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) Format for points with the value of null. Works analogously to format.
nullFormatcan be applied only to series which support displaying null points.heatmapandtilemapsupportsnullFormatby default while the following series requires [#series.nullIfinal - overflow → String?
-
(Highcharts, Highstock, Highmaps, Gantt) How to handle data labels that flow outside the plot area. The default is
"justify", which aligns them inside the plot area. For columns and bars, this means it will be moved inside the bar. To display data labels outside the plot area, setcropto `falsefinal - padding → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) When either the
borderWidthor thebackgroundColoris set, this is the padding within the box.final - position → String?
-
(Highcharts, Highstock, Highmaps, Gantt) Aligns data labels relative to points. If
centeralignment is not possible, it defaults toright.final - rotation → num?
-
(Highcharts, Highstock, Highmaps, Gantt) Text rotation in degrees. Note that due to a more complex structure, backgrounds, borders and padding will be lost on a rotated data label.
final
- rotationMode → String?
-
(Highcharts, Highstock, Highmaps, Gantt) Decides how the data label will be rotated relative to the perimeter of the sunburst. Valid values are
circular,auto,parallelandperpendicular. Whencircular, the best fit will be computed for the point, so that the label is curved around the cenfinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) The shadow of the box. Works best with
borderWidthorbackgroundColor. Since 2.3 the shadow can be an object configuration containingcolor,offsetX,offsetY,opacityandwidth.final - shape → String?
-
(Highcharts, Highstock, Highmaps, Gantt) The name of a symbol to use for the border around the label. Symbols are predefined functions on the Renderer object.
final
- softConnector → bool?
-
(Highcharts, Highmaps) Whether to render the connector as a soft arc or a line with a sharp break. Works only if
connectorShapeequals tofixedOffset.final - style → dynamic
-
(Highcharts, Highstock, Highmaps, Gantt) Styles for the label. The default
colorsetting is"contrast", which is a pseudo color that Highcharts picks up and applies the maximum contrast to the underlying point item, for example the bar in a bar chart.final - textPath → HCDataLabelsTextPathOptionsObject?
-
(Highcharts, Highstock, Highmaps, Gantt) Options for a label text which should follow marker's shape. Border and background are disabled for a label that follows a path.
final
- useHTML → bool?
-
(Highcharts, Highstock, Highmaps, Gantt) Whether to use HTML to render the labels.
final
- verticalAlign → String?
-
(Highcharts, Highstock, Highmaps, Gantt) The vertical alignment of a data label. Can be one of
top,middleorbottom. The default value depends on the data, for instance in a column chart, the label is above positive values and below negative values.final - x → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The x position offset of the label relative to the point in pixels.
final
- y → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The y position offset of the label relative to the point in pixels.
final
- zIndex → num?
-
(Highcharts, Highstock, Highmaps, Gantt) The z index of the data labels group. Does not apply below series level options.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited