threshold property

num? threshold
final

(Highcharts) The Y axis value to serve as the base for the columns, for distinguishing between values above and below a threshold. If null, the columns extend from the padding Y axis minimum.

Implementation

final num? threshold;