HCXAxisCurrentDateIndicatorLabelOptions class

(Gantt) Text labels for the plot lines

Implemented types

Constructors

HCXAxisCurrentDateIndicatorLabelOptions({String? align, dynamic format, num? rotation, HCCSSObject? style, String? text, String? textAlign, bool? useHTML, String? verticalAlign, num? x, num? y})
const

Properties

align String?
(Gantt) Horizontal alignment of the label. Can be one of "left", "center" or "right".
final
format → dynamic
(Gantt) Format of the label. This options is passed as the first argument to dateFormat function.
final
hashCode int
The hash code for this object.
no setterinherited
rotation num?
(Gantt) Rotation of the text label in degrees. Defaults to 0 for horizontal plot lines and 90 for vertical lines.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style HCCSSObject?
(Gantt) CSS styles for the text label.
final
text String?
(Gantt) The text itself. A subset of HTML is supported.
final
textAlign String?
(Gantt) The text alignment for the label. While align determines where the texts anchor point is placed within the plot band, textAlign determines how the text is aligned against its anchor point. Possible values are "left", "center" and "right". Defaults to the same as the align option.
final
useHTML bool?
(Gantt) Whether to use HTML to render the labels.
final
verticalAlign String?
(Gantt) Vertical alignment of the label relative to the plot line. Can be one of "top", "middle" or "bottom".
final
x num?
(Gantt) Horizontal position relative the alignment. Default varies by orientation.
final
y num?
(Gantt) Vertical position of the text baseline relative to the alignment. Default varies by orientation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited