includeInDataExport property
(Highstock) When set to false will prevent the series data from being included in any form of data export.
Implementation
final bool? includeInDataExport;
(Highstock) When set to false will prevent the series data from being included in any form of data export.
final bool? includeInDataExport;