name property
(Highcharts, Highstock, Highmaps, Gantt) The name of the series as shown in the legend, tooltip etc. If a dataTable and dataMapping are used, the name defaults to the id of the primary data table column. Otherwise, it defaults to "Series {n}", where n is the index of the series, starting at 1.
Implementation
final String? name;