labelrank property
(Highmaps) When data labels are laid out on a map, Highmaps runs a simplified algorithm to detect collision. When two labels collide, the one with the lowest rank is hidden. By default the rank is computed from the area.
Implementation
final num? labelrank;